Struct rustc_mir::transform::simplify::SimplifyCfg
[−]
[src]
pub struct SimplifyCfg { /* fields omitted */ }🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?
Methods
impl SimplifyCfg[src]
pub fn new(label: &str) -> Self[src]
🔬 This is a nightly-only experimental API. (rustc_private)
this crate is being loaded from the sysroot, an unstable location; did you mean to load this crate from crates.io via Cargo.toml instead?